abacusai.file_connector_verification — AbacusAI documentation

# abacusai.file_connector_verification

## Classes

`FileConnectorVerification` | To verify the file connector

## Module Contents

class abacusai.file_connector_verification.FileConnectorVerification(client, verified=None, writePermission=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  To verify the file connector

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - verified (bool) – true if the bucket has passed verification

    - writePermission (bool) – true if Abacus.AI has permission to write to this bucket

  verified
  write_permission
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict